Learn R Programming

riskdiff (version 0.3.0)

.transform_to_nnt: Transform Risk Difference Results to Number Needed to Treat

Description

Converts risk difference estimates and confidence intervals to Number Needed to Treat (NNT) using the reciprocal transformation with appropriate handling of boundary cases.

Usage

.transform_to_nnt(rd_results, nnt_threshold = 0.001)

Value

A tibble with NNT estimates and confidence intervals

Arguments

rd_results

A tibble with risk difference results from calc_risk_diff

nnt_threshold

Minimum absolute risk difference for meaningful NNT (default: 0.001)

References

Laupacis A, Sackett DL, Roberts RS (1988). "An assessment of clinically useful measures of the consequences of treatment." New England Journal of Medicine, 318(26), 1728-1733. doi:10.1056/NEJM198806303182605

Cook RJ, Sackett DL (1995). "The number needed to treat: a clinically useful measure of treatment effect." BMJ, 310(6977), 452-454. doi:10.1136/bmj.310.6977.452